@@ -1,7 +1,7 @@
 package Spreadsheet::XLSX::Reader::LibXML::FmtDefault;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = qv('v0.38.6');
-###LogSD	warn "You uncovered logging statements for Spreadsheet::XLSX::Reader::LibXML::FmtDefault-$VERSION";
+use version; our $VERSION = qv('v0.38.8');
+###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML::FmtDefault-$VERSION";
 
 use	5.010;
 use	Moose;
@@ -152,7 +152,7 @@ sub	set_defined_excel_formats{
 
 sub	change_output_encoding{
 	my ( $self, $string, ) = @_;
-	return undef if !$string;
+	return undef if !defined $string;
 	###LogSD	my	$phone = Log::Shiras::Telephone->new(
 	###LogSD				name_space 	=> $self->get_log_space . '::change_output_encoding', );
 	###LogSD		$phone->talk( level => 'info', message => [
